@@ -1,3 +1,35 @@
+# -*- coding: utf-8 -*-
+"""
+
+
+Todo:
+    * Use config as much as possible
+
+"""
+__author__ = "Anders Åström"
+__contact__ = "anders@lyngon.com"
+__copyright__ = "2021, Lyngon Pte. Ltd."
+__licence__ = """The MIT License
+Copyright © 2021 Lyngon Pte. Ltd.
+
+Permission is hereby granted, free of charge, to any person obtaining a copy of this
+ software and associated documentation files (the “Software”), to deal in the Software
+ without restriction, including without limitation the rights to use, copy, modify,
+ merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
+ permit persons to whom the Software is furnished to do so, subject to the following
+ conditions:
+
+The above copyright notice and this permission notice shall be included in all copies
+ or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
+ INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
+ PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
+ HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
+ CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
+ OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+"""
+
 import sys
 
 from .func import trigger
@@ -37,15 +69,27 @@ __all__ = [
 
 try:
     # This will fail if redis package is not installed
-    from .client import Gears, Redis, RedisGears
+    from .client import Gears, Redis
+
+    __all__ += ["Gears", "Redis"]
+
+    try:
+        # This will fail if redis-py-cluster package is not installed
+        from .cluster import RedisCluster, RedisGears
+
+        __all__ += ["RedisCluster"]
+    except ModuleNotFoundError:
+        from .client import Redis as RedisGears
+
+    __all__ += ["RedisGears"]
 
-    __all__ += ["Gears", "Redis", "RedisGears"]
 except ModuleNotFoundError:
     pass
 
+
 try:
     # This will fail if redis package is not installed
-    from .command import redis as cmd
+    from .command import cmd
 
     __all__ += ["cmd"]
 except ModuleNotFoundError:
